==> nextcloud-app-mail-0.17.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/eo.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Retpoŝtilo",
    "Inbox" : "Ricevujo",
    "Sent" : "Senditujo",
    "Drafts" : "Malnetujo",
    "Archive" : "Arĥivujo",
    "Trash" : "Rubujo",
    "Junk" : "Trudmesaĝujo",
    "All" : "Ĉio",
    "Favorites" : "Pliŝataĵoj",
    "Auto detect failed. Please use manual mode." : "Aŭtomata rekono malsukcesis. Bv. uzi permanan reĝimon.",
    "Updating account failed: " : "Ĝisdatigo de konto malsukcesis:",
    "Creating account failed: " : "Kreo de konto malsukcesis:",
    "Delete permanently" : "Forigi por ĉiam",
    "Auto" : "Aŭtomate",
    "Name" : "Nomo",
    "Mail Address" : "Retpoŝtadreso",
    "Password" : "Pasvorto",
    "Manual" : "Permane",
    "IMAP Settings" : "IMAP-agordoj",
    "IMAP Host" : "IMAP-gastigo",
    "IMAP Security" : "IMAP-sekureco",
    "None" : "Nenio",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-pordo",
    "IMAP User" : "IMAP-uzanto",
    "IMAP Password" : "IMAP-pasvorto",
    "SMTP Settings" : "SMTP-agordoj",
    "SMTP Host" : "SMTP-gastigo",
    "SMTP Security" : "SMTP-sekureco",
    "SMTP Port" : "SMTP-pordo",
    "SMTP User" : "SMTP-uzanto",
    "SMTP Password" : "SMTP-pasvorto",
    "Save" : "Konservi",
    "Connect" : "Konekti",
    "Add mail account" : "Aldoni retpoŝtan konton",
    "Use Gravatar and favicon avatars" : "Uzi servon „Gravatar“ kaj avatarojn en retpaĝsimbolo",
    "Keyboard shortcuts" : "Fulmoklavoj",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Ĉu vi serĉas manieron ĉifri viajn mesaĝojn? Instalu la retumilan kromprogramon „Mailvelope“!",
    "from" : "el",
    "to" : "al",
    "+ cc/bcc" : "+ kopioj",
    "cc" : "kopio",
    "bcc" : "kaŝkopio",
    "Subject" : "Temo",
    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Atentu, ke tiu retmesaĝo devenis el adreso „noreply“ (angle por „bv. ne respondi“): neniu probable legos vian respondon.",
    "Message …" : "Mesaĝo...",
    "Saving draft …" : "Konservado de malneto...",
    "Draft saved" : "Malneto konservita",
    "Uploading attachments …" : "Alŝutado de kunsendaĵoj...",
    "Sending …" : "Sendante...",
    "Error sending your message" : "Eraro dum sendo de via mesaĝo",
    "Go back" : "Reveni",
    "Retry" : "Reprovi",
    "Message sent!" : "Mesaĝo sendiĝis!",
    "Reply sent!" : "Respondo sendiĝis!",
    "Write another message" : "Verki alian mesaĝon",
    "Send" : "Sendi",
    "Uploading {percent}% …" : "Alŝutante {percent} %…",
    "Upload attachment" : "Alŝuti kunsendaĵon",
    "Add attachment from Files" : "Aldoni kunsendaĵojn el „Dosieroj“",
    "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
    "No messages in this folder" : "Neniu mesaĝo en tiu dosierujo",
    "Draft: " : "Malneto:",
    "Mark read" : "Marki kiel legita",
    "Mark unread" : "Marki kiel nelegita",
    "Delete" : "Forigi",
    "Report this bug" : "Raporti tiun problemon",
    "Loading messages" : "Ŝargante mesaĝojn",
    "Not found" : "Ne trovita",
    "Could not load your message" : "Ne eblis ŝargi vian mesaĝon",
    "Import into calendar" : "Importi en kalendaron",
    "Download attachment" : "Elŝuti kunsendaĵon",
    "Save to Files" : "Konservi en „Dosieroj“",
    "Choose a folder to store the attachment in" : "Elektu dosierujon en kiu konservi la kunsendaĵon",
    "Save all to Files" : "Konservi ĉiujn al „Dosieroj“",
    "Choose a folder to store the attachments in" : "Elektu dosierujon en kiu konservi la kunsendaĵojn",
    "The images have been blocked to protect your privacy." : "Bildoj ne montriĝis por protekti vian privatecon.",
    "Show images from this\tsender" : "Montri bildojn el tiu sendinto",
    "New message" : "Nova mesaĝo",
    "Settings" : "Agordoj",
    "Edit" : "Modifi",
    "Add folder" : "Aldoni dosierujon",
    "Show all folders" : "Montri ĉiujn dosierujojn",
    "Collapse folders" : "Maletendi dosierujojn",
    "Loading …" : "Ŝargado...",
    "{total} messages ({unread} unread)" : "{total} mesaĝoj ({unread} ne legitaj)",
    "Mark all as read" : "Marki ĉion kiel legita",
    "Mark all messages of this folder as read" : "Marki ĉiujn mesaĝojn el tiu dosierujo kiel legitaj",
    "Add subfolder" : "Aldoni subdosierujon",
    "Could not load your draft" : "Ne eblis ŝargi vian malneton",
    "No message selected" : "Neniu mesaĝo elektita",
    "Signature" : "Subskribo",
    "A signature will be added to the text of new and response messages." : "Subskribo aldoniĝos al la teksto de novaj kaj respondaj mesaĝoj.",
    "Account Settings" : "Kontaj agordoj",
    "Mail server" : "Retpoŝtoservilo",
    "Speed up your Mail experience with these quick shortcuts." : "Plirapidiĝu per tiuj fulmoklavoj.",
    "Compose new message" : "Krei novan mesaĝon",
    "Newer message" : "Pli nova mesaĝo",
    "Older message" : "Pli malnova mesaĝo",
    "Toggle star" : "Baskuligi stelon",
    "Toggle unread" : "Baskuligi legostaton",
    "Search" : "Serĉi",
    "Refresh" : "Aktualigi",
    "Connect your mail account" : "Konekti vian retpoŝtan konton",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nova mesaĝo\nel {from}","%n novaj mesaĝoj \nel {from}"],
    "Nextcloud Mail" : "Nextcloud-retpoŝtilo",
    "All inboxes" : "Ĉiuj ricevujoj",
    "Could not load {tag}{name}{endtag}" : "Ne eblis ŝargi {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Problemo okazis dum ŝargo de {tag}{name}{endtag}",
    "Could not load the desired message" : "Ne eblis ŝargi la deziratan mesaĝon",
    "Could not load the message" : "Ne eblis ŝargi la mesaĝon",
    "Error loading message" : "Eraro dum ŝargo de mesaĝo",
    "Forwarding to %s" : "Plusendi al %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Alklaku ĉi tie, ĉu vi ne estos aŭtomate alidirektita post kelkaj sekundoj.",
    "Redirect" : "Alidirekto",
    "The link leads to %s" : "La ligilo iras al %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se vi ne volas viziti tiun paĝon, vi povas reiri al <a href=\"%s\">retpoŝtilo</a>.",
    "Continue to %s" : "Daŭrigi al %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-0.18.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/eo.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Retpoŝtilo",
    "Auto detect failed. Please use manual mode." : "Aŭtomata rekono malsukcesis. Bv. uzi permanan reĝimon.",
    "Updating account failed: " : "Ĝisdatigo de konto malsukcesis:",
    "Creating account failed: " : "Kreo de konto malsukcesis:",
    "Auto" : "Aŭtomate",
    "Name" : "Nomo",
    "Mail Address" : "Retpoŝtadreso",
    "Password" : "Pasvorto",
    "Manual" : "Permane",
    "IMAP Settings" : "IMAP-agordoj",
    "IMAP Host" : "IMAP-gastigo",
    "IMAP Security" : "IMAP-sekureco",
    "None" : "Nenio",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-pordo",
    "IMAP User" : "IMAP-uzanto",
    "IMAP Password" : "IMAP-pasvorto",
    "SMTP Settings" : "SMTP-agordoj",
    "SMTP Host" : "SMTP-gastigo",
    "SMTP Security" : "SMTP-sekureco",
    "SMTP Port" : "SMTP-pordo",
    "SMTP User" : "SMTP-uzanto",
    "SMTP Password" : "SMTP-pasvorto",
    "Save" : "Konservi",
    "Connect" : "Konekti",
    "Add mail account" : "Aldoni retpoŝtan konton",
    "Use Gravatar and favicon avatars" : "Uzi servon „Gravatar“ kaj avatarojn en retpaĝsimbolo",
    "Keyboard shortcuts" : "Fulmoklavoj",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Ĉu vi serĉas manieron ĉifri viajn mesaĝojn? Instalu la retumilan kromprogramon „Mailvelope“!",
    "Subject" : "Temo",
    "Saving draft …" : "Konservado de malneto...",
    "Draft saved" : "Malneto konservita",
    "Uploading attachments …" : "Alŝutado de kunsendaĵoj...",
    "Sending …" : "Sendado...",
    "Error sending your message" : "Eraro dum sendo de via mesaĝo",
    "Go back" : "Reveni",
    "Retry" : "Reprovi",
    "Message sent!" : "Mesaĝo sendiĝis!",
    "Reply sent!" : "Respondo sendiĝis!",
    "Write another message" : "Verki alian mesaĝon",
    "Send" : "Sendi",
    "Uploading {percent}% …" : "Alŝutado {percent} %…",
    "Upload attachment" : "Alŝuti kunsendaĵon",
    "Add attachment from Files" : "Aldoni kunsendaĵojn el „Dosieroj“",
    "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
    "No messages in this folder" : "Neniu mesaĝo en tiu dosierujo",
    "Draft: " : "Malneto:",
    "Mark read" : "Marki kiel legita",
    "Mark unread" : "Marki kiel nelegita",
    "Delete" : "Forigi",
    "Report this bug" : "Raporti tiun problemon",
    "Loading messages" : "Ŝargo de mesaĝoj",
    "Not found" : "Ne trovita",
    "Could not load your message" : "Ne eblis ŝargi vian mesaĝon",
    "Import into calendar" : "Importi en kalendaron",
    "Download attachment" : "Elŝuti kunsendaĵon",
    "Save to Files" : "Konservi en „Dosieroj“",
    "Choose a folder to store the attachment in" : "Elektu dosierujon en kiu konservi la kunsendaĵon",
    "Save all to Files" : "Konservi ĉiujn al „Dosieroj“",
    "Choose a folder to store the attachments in" : "Elektu dosierujon en kiu konservi la kunsendaĵojn",
    "The images have been blocked to protect your privacy." : "Bildoj ne montriĝis por protekti vian privatecon.",
    "Show images from this\tsender" : "Montri bildojn el tiu sendinto",
    "New message" : "Nova mesaĝo",
    "Settings" : "Agordoj",
    "Add folder" : "Aldoni dosierujon",
    "Show all folders" : "Montri ĉiujn dosierujojn",
    "Collapse folders" : "Maletendi dosierujojn",
    "Mark all as read" : "Marki ĉion kiel legita",
    "Add subfolder" : "Aldoni subdosierujon",
    "Could not load your draft" : "Ne eblis ŝargi vian malneton",
    "No message selected" : "Neniu mesaĝo elektita",
    "Signature" : "Subskribo",
    "Mail server" : "Retpoŝtoservilo",
    "Speed up your Mail experience with these quick shortcuts." : "Plirapidiĝu per tiuj fulmoklavoj.",
    "Compose new message" : "Krei novan mesaĝon",
    "Newer message" : "Pli nova mesaĝo",
    "Older message" : "Pli malnova mesaĝo",
    "Toggle star" : "Baskuligi stelon",
    "Toggle unread" : "Baskuligi legostaton",
    "Search" : "Serĉi",
    "Refresh" : "Aktualigi",
    "Connect your mail account" : "Konekti vian retpoŝtan konton",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nova mesaĝo\nel {from}","%n novaj mesaĝoj \nel {from}"],
    "Nextcloud Mail" : "Nextcloud-retpoŝtilo",
    "All inboxes" : "Ĉiuj ricevujoj",
    "Could not load {tag}{name}{endtag}" : "Ne eblis ŝargi {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Problemo okazis dum ŝargo de {tag}{name}{endtag}",
    "Could not load the desired message" : "Ne eblis ŝargi la deziratan mesaĝon",
    "Could not load the message" : "Ne eblis ŝargi la mesaĝon",
    "Error loading message" : "Eraro dum ŝargo de mesaĝo",
    "Forwarding to %s" : "Plusendi al %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Alklaku ĉi tie, ĉu vi ne estos aŭtomate alidirektita post kelkaj sekundoj.",
    "Redirect" : "Alidirekto",
    "The link leads to %s" : "La ligilo iras al %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se vi ne volas viziti tiun paĝon, vi povas reiri al <a href=\"%s\">retpoŝtilo</a>.",
    "Continue to %s" : "Daŭrigi al %s"
},
"nplurals=2; plural=(n != 1);");
